import { Controller, Get, Query } from '@nestjs/common';

import { MODULE_NAME } from 'src/core/strings/constants/module.constants';
import { ApiBearerAuth, ApiTags } from '@nestjs/swagger';

import { Public } from 'src/core/guards';
import { QueueAdminOrchestrator } from '../../domain/queue-admin.orchestrator';
import { PaginationResponse } from 'src/core/response/domain/ok-response.interface';
import { Queue } from '../../domain/entities/queue.entity';
import { QueueDto } from './dto/queue.filter';

@ApiTags(`Queue Admin`)
@Controller(`v1/${MODULE_NAME.QUEUE}-admin`)
@Public(true)
@ApiBearerAuth('JWT')
export class QueueAdminController {
  constructor(private orchestrator: QueueAdminOrchestrator) {}

  @Get('queues')
  async index(@Query() params: QueueDto): Promise<PaginationResponse<Queue>> {
    return await this.orchestrator.index(params);
  }
}
